Module rings

Module rings 

Ring theory structures.

This module defines traits for algebraic structures from rings to integral domains.

Traits

CommutativeRing
Represents a Commutative Ring, an algebraic structure where multiplication is commutative.
IntegralDomain
Represents an Integral Domain, a commutative ring with no zero divisors.
Polynomial
Represents a Polynomial over a ring.
PrincipalIdealDomain
Represents a Principal Ideal Domain (PID), an integral domain where every ideal is principal.
Ring
Represents a Ring, an algebraic structure with two binary operations (addition and multiplication) that satisfy certain axioms.
UniqueFactorizationDomain
Represents a Unique Factorization Domain (UFD), an integral domain where every non-zero non-unit element has a unique factorization into irreducible elements.